@@ -32,11 +32,11 @@ Log::AutoDump - Log with automatic dumping of references and objects.
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 $VERSION = eval $VERSION;
 
@@ -439,16 +439,6 @@ sub msg
 
     print $fh $msg;
 
-    if ( scalar @{ $self->{ history } } >= $self->{ history_length } )
-    {
-        shift @{ $self->{ history } };
-    }
-
-    if ( scalar @{ $self->{ history } } < $self->{ history_length } )
-    {
-        push @{ $self->{ history } }, \@things;
-    }
-
     return $self;
 }
 
@@ -463,6 +453,23 @@ sub _flush
     return $self;
 }
 
+sub _add_to_history
+{
+    my ( $self, @things ) = @_;
+
+    if ( scalar @{ $self->{ history } } >= $self->{ history_length } )
+    {
+        shift @{ $self->{ history } };
+    }
+
+    if ( scalar @{ $self->{ history } } < $self->{ history_length } )
+    {
+        push @{ $self->{ history } }, \@things;
+    }
+
+    return $self;
+}
+
 =head4 trace
 
  $log->trace( "Trace some info" );
@@ -475,6 +482,7 @@ sub trace
 {
     my $self = shift;
     $self->msg( TRACE, @_ ) if $self->is_trace;
+    $self->_add_to_history( @_ );
     return $self;
 }
 
@@ -511,6 +519,7 @@ sub debug
     }
 
     $self->msg( DEBUG, @lines ) if $self->is_debug;
+    $self->_add_to_history( @lines );
 
     return $self;
 }
@@ -533,6 +542,7 @@ sub info
 {
     my $self = shift;
     $self->msg( INFO, @_ ) if $self->is_info;
+    $self->_add_to_history( @_ );
     return $self;
 }
 
@@ -553,6 +563,7 @@ sub warn
 {
     my $self = shift;
     $self->msg( WARN, @_ ) if $self->is_warn;
+    $self->_add_to_history( @_ );
     return $self;
 }
 
@@ -573,6 +584,7 @@ sub error
 {
     my $self = shift;
     $self->msg( ERROR, @_ ) if $self->is_error;
+    $self->_add_to_history( @_ );
     return $self;
 }
 
@@ -593,6 +605,7 @@ sub fatal
 {
     my $self = shift;
     $self->msg( FATAL, @_ ) if $self->is_fatal;
+    $self->_add_to_history( @_ );
     return $self;
 }
 
